@@ -1,13 +1,14 @@
 package ExtUtils::Helpers::Unix;
-$ExtUtils::Helpers::Unix::VERSION = '0.026';
+$ExtUtils::Helpers::Unix::VERSION = '0.027';
 use strict;
 use warnings FATAL => 'all';
 
 use Exporter 5.57 'import';
-our @EXPORT = qw/make_executable detildefy/;
+our @EXPORT = qw/make_executable split_like_shell detildefy/;
 
 use Carp qw/croak/;
 use Config;
+use Text::ParseWords 3.24 qw/shellwords/;
 
 my $layer = $] >= 5.008001 ? ":raw" : "";
 
@@ -30,6 +31,16 @@ sub make_executable {
 	return;
 }
 
+sub split_like_shell {
+	my ($string) = @_;
+
+	return if not defined $string;
+	$string =~ s/^\s+|\s+$//g;
+	return if not length $string;
+
+	return shellwords($string);
+}
+
 sub detildefy {
 	my $value = shift;
 	# tilde with optional username
@@ -56,7 +67,7 @@ ExtUtils::Helpers::Unix - Unix specific helper bits
 
 =head1 VERSION
 
-version 0.026
+version 0.027
 
 =for Pod::Coverage make_executable
 split_like_shell
