@@ -1,11 +1,12 @@
 package ExtUtils::Helpers::VMS;
-$ExtUtils::Helpers::VMS::VERSION = '0.025';
+$ExtUtils::Helpers::VMS::VERSION = '0.027';
 use strict;
 use warnings FATAL => 'all';
 
 use Exporter 5.57 'import';
-our @EXPORT = qw/make_executable detildefy/;
+our @EXPORT = qw/make_executable split_like_shell detildefy/;
 
+use ExtUtils::Helpers::Unix qw/split_like_shell/; # Probably very wrong, but whatever
 use File::Copy qw/copy/;
 
 sub make_executable {
@@ -88,7 +89,7 @@ ExtUtils::Helpers::VMS - VMS specific helper bits
 
 =head1 VERSION
 
-version 0.025
+version 0.027
 
 =for Pod::Coverage make_executable
 detildefy
